@@ -10,6 +10,7 @@ import sys
 from datetime import datetime
 
 from boto_session_manager import BotoSesManager, AwsServiceEnum
+from colorama import Fore, Style
 
 from . import exc
 from . import helper
@@ -156,7 +157,18 @@ def upload_template_to_s3(
     template: str,
     bucket: str,
     prefix: T.Optional[str] = None,
-):
+) -> str:
+    """
+    Upload the CloudFormation template body to S3 before deployment.
+    The target location is: s3://${bucket}/${prefix}/${md5_of_template_body}.${json_or_yaml}.
+
+    :param bsm: ``boto_session_manager.BotoSesManager`` object
+    :param template: template Body in string
+    :param bucket: s3 bucket name
+    :param prefix: s3 prefix
+
+    :return: the full s3 uri for the template uploads.
+    """
     s3_client = bsm.get_client(AwsServiceEnum.S3)
     template_type = detect_template_type(template)
     md5 = helper.md5_of_text(template)
@@ -685,7 +697,7 @@ def wait_create_or_update_stack_to_finish(
     :return: a :class:`~aws_cottonformation.stack.Stack` object.
     """
     if verbose:
-        print("  wait for deploy to finish ...")
+        print(f" {Fore.CYAN}wait for deploy to finish{Style.RESET_ALL} ...")
     for _ in Waiter(
         delays=delays,
         timeout=timeout,
@@ -699,7 +711,7 @@ def wait_create_or_update_stack_to_finish(
                     icon = "🟢"
                 else:
                     icon = "🔴"
-                print(f"\n    reached status {icon} {stack.status.value!r}")
+                print(f"\n    reached status {icon} {Fore.CYAN}{stack.status.value!r}{Style.RESET_ALL}")
             return stack
 
 
@@ -724,7 +736,7 @@ def wait_delete_stack_to_finish(
     :return: Nothing
     """
     if verbose:
-        print("  wait for delete to finish ...")
+        print(f"  {Fore.CYAN}wait for delete to finish{Style.RESET_ALL} ...")
     for _ in Waiter(
         delays=delays,
         timeout=timeout,
@@ -739,7 +751,7 @@ def wait_delete_stack_to_finish(
         else:
             if stack.status.is_stopped():
                 if verbose:
-                    print(f"\n    reached status {stack.status.value}")
+                    print(f"\n    reached status {Fore.CYAN}{stack.status.value}{Style.RESET_ALL}")
             return
 
 
@@ -764,7 +776,7 @@ def wait_create_change_set_to_finish(
     :return:
     """
     if verbose:
-        print("  wait for change set creation to finish ...")
+        print(f"  {Fore.CYAN}wait for change set creation to finish{Style.RESET_ALL} ...")
 
     for _ in Waiter(
         delays=delays,
@@ -783,7 +795,7 @@ def wait_create_change_set_to_finish(
             ChangeSetStatusEnum.FAILED.value,
         ]:
             if verbose:
-                print(f"\n    reached status {change_set_status}")
+                print(f"\n    reached status {Fore.CYAN}{change_set_status}{Style.RESET_ALL}")
 
             if change_set_status == ChangeSetStatusEnum.FAILED.value:
                 status_reason = response["StatusReason"]
