@@ -7,6 +7,7 @@ Implement the fancy deployment and remove API with "terraform plan" liked featur
 import typing as T
 
 from boto_session_manager import BotoSesManager
+from colorama import Fore, Style
 
 from . import exc
 from .better_boto import (
@@ -26,6 +27,7 @@ from .better_boto import (
     wait_create_or_update_stack_to_finish,
     wait_delete_stack_to_finish,
     wait_create_change_set_to_finish,
+    StackStatusEnum,
     ChangeSetTypeEnum,
 )
 from .console import (
@@ -100,12 +102,20 @@ def _deploy_stack_without_change_set(
         )
         if verbose:
             console_url = get_stack_details_console_url(stack_id=stack_id)
-            print(f"  preview **create stack progress** at: {console_url}")
+            print(f"  preview {Fore.CYAN}create stack progress{Style.RESET_ALL} at: {console_url}")
     # already exists, do update
     else:
         if verbose:
             console_url = get_stack_details_console_url(stack_id=stack.id)
-            print(f"  preview **update stack progress** at: {console_url}")
+            print(f"  preview {Fore.CYAN}update stack progress{Style.RESET_ALL} at: {console_url}")
+
+        if stack.status == StackStatusEnum.REVIEW_IN_PROGRESS:
+            raise ValueError(
+                f"You cannot update a stack when status is {StackStatusEnum.REVIEW_IN_PROGRESS.value}! "
+                f"It could be because you created the stack using change set, "
+                f"but never take action to approve or deny it. "
+                f"You can delete it and retry."
+            )
 
         if skip_prompt is False:
             if prompt_to_proceed() is False:
@@ -206,6 +216,14 @@ def _deploy_stack_using_change_set(
         create_change_set_kwargs["change_set_type"] = ChangeSetTypeEnum.CREATE.value
     # already exist, do update
     else:
+        if stack.status == StackStatusEnum.REVIEW_IN_PROGRESS:
+            raise ValueError(
+                f"You cannot update a stack when status is {StackStatusEnum.REVIEW_IN_PROGRESS.value}! "
+                f"It could be because you created the stack using change set, "
+                f"but never take action to approve or deny it. "
+                f"You can delete it and retry."
+            )
+
         action = "update"
         create_change_set_kwargs["change_set_type"] = ChangeSetTypeEnum.UPDATE.value
 
@@ -218,7 +236,7 @@ def _deploy_stack_using_change_set(
             stack_id=stack_id,
             change_set_id=change_set_id,
         )
-        print(f"  preview **change set details** at: {console_url}")
+        print(f"  preview {Fore.CYAN}change set details{Style.RESET_ALL} at: {console_url}")
 
     try:
         response = wait_create_change_set_to_finish(
@@ -256,7 +274,7 @@ def _deploy_stack_using_change_set(
 
     if verbose:
         console_url = get_stack_details_console_url(stack_id=stack_id)
-        print(f"  preview **{action} stack progress** at: {console_url}")
+        print(f"  preview {Fore.CYAN}{action} stack progress{Style.RESET_ALL} at: {console_url}")
 
     response = execute_change_set(
         bsm=bsm,
@@ -305,41 +323,58 @@ def deploy_stack(
     verbose: bool = True,
 ):
     """
-    Deploy an AWS CloudFormation stack. But way more powerful than the original
-    boto3 API.
+    Deploy (create or update) an AWS CloudFormation stack. But way more powerful
+    than the original boto3 API.
 
-    :param bsm:
-    :param stack_name:
-    :param template:
-    :param use_previous_template:
-    :param bucket:
-    :param prefix:
-    :param parameters:
-    :param tags:
-    :param execution_role_arn:
-    :param include_iam:
-    :param include_named_iam:
-    :param include_macro:
-    :param stack_policy:
-    :param prefix_stack_policy:
-    :param resource_types:
-    :param client_request_token:
-    :param enable_termination_protection:
-    :param disable_rollback:
-    :param wait:
-    :param delays:
-    :param timeout:
-    :param skip_plan:
-    :param skip_prompt:
-    :param change_set_delays:
-    :param change_set_timeout:
-    :param verbose:
-    :return:
+    Reference:
+
+    - Create Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.create_stack
+    - Update Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.update_stack
+
+    :param bsm: ``boto_session_manager.BotoSesManager`` object
+    :param stack_name: the stack name or unique stack id
+    :param template: CloudFormation template JSON or Yaml body in text, or the
+        s3 uri pointing to a CloudFormation template file.
+    :param use_previous_template: see "Update Stack Boto3 API" link
+    :param bucket: default None; if given, automatically upload template to S3
+        before deployment. see :func:`~aws_cloudformation.better_boto.upload_template_to_s3`
+        for more details.
+    :param prefix: the s3 prefix where you want to upload the template to
+    :param parameters: see "Update Stack Boto3 API" link
+    :param tags: see "Update Stack Boto3 API" link
+    :param execution_role_arn: see "Update Stack Boto3 API" link
+    :param include_iam: see "Capacities" part in "Update Stack Boto3 API" link
+    :param include_named_iam: see "Capacities" part in "Update Stack Boto3 API" link
+    :param include_macro: see "Capacities" part in "Update Stack Boto3 API" link
+    :param stack_policy: Stack Policy JSON or Yaml body in text, or the
+        s3 uri pointing to a Stack Policy JSON template file.
+    :param prefix_stack_policy: see "Update Stack Boto3 API" link
+    :param resource_types: see "Update Stack Boto3 API" link
+    :param client_request_token: see "Update Stack Boto3 API" link
+    :param enable_termination_protection: see "Create Stack Boto3 API" link
+    :param disable_rollback: see "Update Stack Boto3 API" link
+    :param wait: default True; if True, then wait the create / update action
+        to success or fail; if False, then it is an async call and return immediately;
+        note that if you have skip_plan is False (using change set), you always
+        have to wait the change set creation to finish.
+    :param delays: how long it waits (in seconds) between two
+        "describe_stacks" api call to get the stack status
+    :param timeout: how long it will raise timeout error
+    :param skip_plan: default False; if False, force to use change set to
+        create / update; if True, then do create / update without change set.
+    :param skip_prompt: default False; if False, you have to enter "Yes"
+        in prompt to do deployment; if True, then execute the deployment directly.
+    :param change_set_delays: how long it waits (in seconds) between two
+        "describe_change_set" api call to get the change set status
+    :param change_set_timeout: how long it will raise timeout error
+    :param verbose: whether you want to log information to console
+
+    :return: Nothing
 
     .. versionadded:: 0.1.1
     """
     if verbose:
-        print_header(f"Deploy stack: {stack_name!r}", "=", 80)
+        print_header(f"{Fore.CYAN}Deploy{Style.RESET_ALL} stack: {Fore.CYAN}{stack_name}{Style.RESET_ALL}", "=", 80)
         console_url = get_stacks_view_console_url(stack_name=stack_name)
         print(f"  preview stack in AWS CloudFormation console: {console_url}")
 
@@ -416,21 +451,29 @@ def remove_stack(
     """
     Remove an AWS CloudFormation Stack.
 
-    :param bsm:
-    :param stack_name:
-    :param retain_resources:
-    :param role_arn:
-    :param client_request_token:
-    :param wait:
-    :param delays:
-    :param timeout:
-    :param skip_prompt:
-    :param verbose:
-    :return:
+    Reference:
+
+    - Delete Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.delete_stack
+
+    :param bsm: ``boto_session_manager.BotoSesManager`` object
+    :param stack_name: the stack name or unique stack id
+    :param retain_resources: see "Delete Stack Boto3 API" link
+    :param role_arn: see "Delete Stack Boto3 API" link
+    :param client_request_token: see "Delete Stack Boto3 API" link
+    :param wait: default True; if True, then wait the delete action
+        to success or fail; if False, then it is an async call and return immediately.
+    :param delays: how long it waits (in seconds) between two
+        "describe_stacks" api call to get the stack status
+    :param timeout: how long it will raise timeout error
+    :param skip_prompt: default False; if False, you have to enter "Yes"
+        in prompt to do deletion; if True, then execute the deletion directly.
+    :param verbose: whether you want to log information to console
+
+    :return: Nothing
     
     .. versionadded:: 0.1.1
     """
-    print_header(f"Remove stack {stack_name!r}", "=", 80)
+    print_header(f"{Fore.CYAN}Remove{Style.RESET_ALL} stack {Fore.CYAN}{stack_name}{Style.RESET_ALL}", "=", 80)
 
     if verbose:
         console_url = get_stacks_view_console_url(stack_name)
